window.Gleam.initSearch([{"doc":"glychee","title":"glychee","content":"# Glychee\n\n[![Package Version](https://img.shields.io/hexpm/v/glychee)](https://hex.pm/packages/glychee)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3)](https://hexdocs.pm/glychee/)\n\nA simple gleam benchmark runner which wraps\n&lt;https://github.com/bencheeorg/benchee&gt;.\n\n## Quick start\n\n_Notice: Requires at least gleam 0.24 (or gleam 0.0.0-nightly-221019 or later)._\n\nAlso requires elixir and hex to be installed. You might be required to run\n`mix local.hex` after installing elixir.\n\n1. Add glychee to your project: `gleam add glychee`.\n2. Create a a custom benchmarking module that contains a `main`-function.\n   See `glychee_example_benchmark_module.gleam` as an example.\n   In that module you will define which `Function`s to benchmark with one or\n   many `Data`.\n3. Run the benchmark. `bin/glychee_example_benchmark_call.sh` in this\n   library&#39;s source shows an example on how do do it:\n\n### Example\n\nIf you do not have a project yet, create it with:\n\n```sh\ngleam new foobar\ncd foobar\n```\n\nCreate a file named `src/benchmark.gleam` with following contents:\n\n```gleam\nif erlang {\n  import glychee/benchmark\n  import gleam/list\n  import gleam/int\n\n  pub fn main() {\n    benchmark.run(\n      [\n        benchmark.Function(\n          label: &quot;list.sort()&quot;,\n          fun: fn(test_data) {\n            fn() {\n              list.sort(test_data, int.compare)\n            }\n          },\n        ),\n      ],\n      [\n        benchmark.Data(\n          label: &quot;pre-sorted list&quot;,\n          data: list.range(1, 100_000),\n        ),\n        benchmark.Data(\n          label: &quot;reversed list&quot;,\n          data: list.range(1, 100_000)\n          |&gt; list.reverse,\n        ),\n      ],\n    )\n  }\n}\n```\n\nThen run via:\n\n```sh\ngleam clean &amp;&amp; \\\ngleam build &amp;&amp; \\\nerl -pa ./build/dev/erlang/*/ebin -noshell -eval &#39;gleam@@main:run(benchmark)&#39;\n```\n\n## Installation\n\nIf available on Hex this package can be added to your Gleam project:\n\n```sh\ngleam add glychee\n```\n\nGlychee&#39;s documentation can be found at &lt;https://hexdocs.pm/glychee&gt;.\n\n## License\n\nApache 2.0\n","url":"index.html"},{"doc":"glychee/benchmark","title":"Data","content":"pub type Data(data) {\n  Data(label: String, data: data)\n}\n Data pairs arbitrary data, such as a List(Int) with a label\n\n The label is used as part of the benchmark&#39;s stdout output.\n\nData(label: String, data: data)\n\n\nSynonyms:\nglychee/benchmark.Data\nglychee/benchmark Data","url":"glychee/benchmark.html#Data"},{"doc":"glychee/benchmark","title":"Function","content":"pub type Function(test_data, any) {\n  Function(label: String, fun: fn(test_data) -&gt; any)\n}\n Function pairs a `label` with a function returning a callable.\n The function requires some `test_data`.\n\n The label is used as part of the benchmark&#39;s stdout output.\n\nFunction(label: String, fun: fn(test_data) -&gt; any)\n\n\nSynonyms:\nglychee/benchmark.Function\nglychee/benchmark Function","url":"glychee/benchmark.html#Function"},{"doc":"glychee/benchmark","title":"run","content":"pub fn run(function_sets: List(Function(a, b)), data_sets: List(\n    Data(a),\n  )) -&gt; Nil\n Takes a List of Function and List of Data and runs benchmarks for each\n Function combined with each Data grouped by Data first and Function\n second.\n\n Utilized Benchee and its&#39;s stdout output for the function benchmarking.\n\nSynonyms:\nglychee/benchmark.run\nglychee/benchmark run","url":"glychee/benchmark.html#run"},{"doc":"glychee/benchmark","title":"glychee/benchmark","content":" Benchmark\n\n Contain&#39;s custom types and a runner function to process those.\n\n ### Example\n\n ```gleam\n // In src/benchmark.gleam\n import glychee/benchmark\n import gleam/list\n import gleam/int\n\n pub fn main() {\n \tbenchmark.run(\n \t\t[\n \t\t\tbenchmark.Function(\n \t\t\t\tlabel: &quot;list.sort()&quot;,\n \t\t\t\tfun: fn(test_data) {\n          fn() {\n            list.sort(test_data, int.compare)\n          }\n        },\n \t\t\t),\n \t\t],\n \t\t[\n \t\t\tbenchmark.Data(\n        label: &quot;pre-sorted list&quot;,\n        data: list.range(1, 100_000)\n      ),\n \t\t\tbenchmark.Data(\n \t\t\t\tlabel: &quot;reversed list&quot;,\n \t\t\t\tdata: list.range(1, 100_000)\n \t\t\t\t|&gt; list.reverse,\n \t\t\t)\n \t\t],\n \t)\n }\n ```\n\n Run via:\n\n ```\n gleam clean &amp;&amp; \\\n gleam build &amp;&amp; \\\n erl -pa ./build/dev/erlang/*/ebin -noshell -eval &#39;gleam@@main:run(benchmark)&#39;\n ```","url":"glychee/benchmark.html"},{"doc":"glychee_example_benchmark_module","title":"main","content":"pub fn main() -&gt; Nil\n Main function so that this call can succeed:\n `erl -pa ./build/dev/erlang/*/ebin -noshell -eval &#39;gleam@@main:run(glychee_example_benchmark_module)&#39;`\n\nSynonyms:\nglychee_example_benchmark_module.main\nglychee_example_benchmark_module main","url":"glychee_example_benchmark_module.html#main"},{"doc":"glychee_example_benchmark_module","title":"glychee_example_benchmark_module","content":" Example module not to be called directly but could be mimicked in your\n application or library.\n","url":"glychee_example_benchmark_module.html"}]);